@@ -66,6 +66,9 @@ class Ksuid:
 
         return base62.encode(int.from_bytes(bytes(self), "big")).zfill(27)
 
+    def __repr__(self):
+        return str(self)
+
     def __bytes__(self):
         return self.__uid
 
@@ -73,7 +76,7 @@ class Ksuid:
         return self.__uid == other.__uid
 
     def __lt__(self, other):
-        return self.timestamp < other.timestamp
+        return self.__uid < other.__uid
 
     def __hash__(self):
         return int.from_bytes(self.__uid, "big")
